@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Conflicts;
 {
-  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.10';
+  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.11';
 }
 BEGIN {
   $Dist::Zilla::Plugin::Conflicts::AUTHORITY = 'cpan:DROLSKY';
@@ -97,6 +97,16 @@ sub register_prereqs {
         { phase => 'runtime' },
         'Dist::CheckConflicts' => '0.02',
     );
+
+    for my $phase (qw( develop runtime )) {
+        $self->zilla->register_prereqs(
+            {
+                phase => $phase,
+                type  => 'conflicts',
+            },
+            %{ $self->_conflicts() },
+        );
+    }
 }
 
 sub gather_files {
@@ -360,7 +370,7 @@ Dist::Zilla::Plugin::Conflicts - Declare conflicts for your distro
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -388,6 +398,9 @@ L<Dist::CheckConflicts>.
 Second, it adds code to your F<Makefile.PL> or F<Build.PL> to load the
 generated module and print warnings if conflicts are detected.
 
+Third, it adds "conflicts" entries to the develop and runtime prereqs, per
+CPAN Meta Spec (https://metacpan.org/module/CPAN::Meta::Spec#Prereq-Spec).
+
 Finally, it adds the conflicts to the F<META.json> and/or F<META.yml> files
 under the "x_breaks" key.
 
